pub(crate) fn normalize_string<E: AsRef<Expression>>(
expr: E,
) -> ClosureExpressionExpand description
Returns an expression that is the normalized version of the given string expression.
pub(crate) fn normalize_string<E: AsRef<Expression>>(
expr: E,
) -> ClosureExpressionReturns an expression that is the normalized version of the given string expression.